@@ -6,9 +6,9 @@
 # non-discriminant parts of a URL.
 #
 import re
-import pycountry
 from os.path import splitext
 
+from ural.data import ISO_3166_1_COUNTRIES_ALPHA_2
 from ural.ensure_protocol import ensure_protocol
 from ural.infer_redirection import infer_redirection as resolve
 from ural.utils import (
@@ -125,12 +125,13 @@ def strip_lang_subdomains_from_netloc(netloc):
         if len(subdomain) == 5 and "-" in subdomain:
             lang, country = subdomain.split("-", 1)
             if len(lang) == 2 and len(country) == 2:
-                if pycountry.countries.get(
-                    alpha_2=lang.upper()
-                ) and pycountry.countries.get(alpha_2=country.upper()):
+                if (
+                    lang.upper() in ISO_3166_1_COUNTRIES_ALPHA_2
+                    and country.upper() in ISO_3166_1_COUNTRIES_ALPHA_2
+                ):
                     netloc = remaining_netloc
         elif len(subdomain) == 2:
-            if pycountry.countries.get(alpha_2=subdomain.upper()):
+            if subdomain.upper() in ISO_3166_1_COUNTRIES_ALPHA_2:
                 netloc = remaining_netloc
 
     return netloc
@@ -203,6 +204,7 @@ def normalize_url(
         has_protocol = bool(url.scheme)
         splitted = url
     else:
+        url = url.strip()
         has_protocol = PROTOCOL_RE.match(url)
 
         # Ensuring scheme so parsing works correctly
@@ -348,25 +350,8 @@ def normalize_url(
     return result
 
 
-def get_normalized_hostname(
-    url, normalize_amp=True, strip_lang_subdomains=False, infer_redirection=True
-):
-
-    if infer_redirection:
-        url = resolve(url)
-
-    if isinstance(url, SplitResult):
-        splitted = url
-    else:
-        try:
-            splitted = urlsplit(ensure_protocol(url))
-        except ValueError:
-            return None
-
-    if not splitted.hostname:
-        return None
-
-    hostname = splitted.hostname.lower()
+def normalize_hostname(hostname, normalize_amp=True, strip_lang_subdomains=False):
+    hostname = hostname.strip().lower()
 
     pattern = IRRELEVANT_SUBDOMAIN_AMP_RE if normalize_amp else IRRELEVANT_SUBDOMAIN_RE
 
@@ -381,3 +366,27 @@ def get_normalized_hostname(
         hostname = strip_lang_subdomains_from_netloc(hostname)
 
     return hostname
+
+
+def get_normalized_hostname(
+    url, normalize_amp=True, strip_lang_subdomains=False, infer_redirection=True
+):
+    if infer_redirection:
+        url = resolve(url)
+
+    if isinstance(url, SplitResult):
+        splitted = url
+    else:
+        try:
+            splitted = urlsplit(ensure_protocol(url.strip()))
+        except ValueError:
+            return None
+
+    if not splitted.hostname:
+        return None
+
+    return normalize_hostname(
+        splitted.hostname,
+        normalize_amp=normalize_amp,
+        strip_lang_subdomains=strip_lang_subdomains,
+    )
